==> knative-model-5.0.2-sources.jar: annotations/io/fabric8/knative/eventing/contrib/github/v1alpha1/GitHubSourceFluent.java <==
package io.fabric8.knative.eventing.contrib.github.v1alpha1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface GitHubSourceFluent<A extends GitHubSourceFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public GitHubSourceFluent.MetadataNested<A> withNewMetadata();
    public GitHubSourceFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public GitHubSourceFluent.MetadataNested<A> editMetadata();
    public GitHubSourceFluent.MetadataNested<A> editOrNewMetadata();
    public GitHubSourceFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public GitHubSourceSpec getSpec();
    public GitHubSourceSpec buildSpec();
    public A withSpec(GitHubSourceSpec spec);
    public Boolean hasSpec();
    public GitHubSourceFluent.SpecNested<A> withNewSpec();
    public GitHubSourceFluent.SpecNested<A> withNewSpecLike(GitHubSourceSpec item);
    public GitHubSourceFluent.SpecNested<A> editSpec();
    public GitHubSourceFluent.SpecNested<A> editOrNewSpec();
    public GitHubSourceFluent.SpecNested<A> editOrNewSpecLike(GitHubSourceSpec item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public GitHubSourceStatus getStatus();
    public GitHubSourceStatus buildStatus();
    public A withStatus(GitHubSourceStatus status);
    public Boolean hasStatus();
    public GitHubSourceFluent.StatusNested<A> withNewStatus();
    public GitHubSourceFluent.StatusNested<A> withNewStatusLike(GitHubSourceStatus item);
    public GitHubSourceFluent.StatusNested<A> editStatus();
    public GitHubSourceFluent.StatusNested<A> editOrNewStatus();
    public GitHubSourceFluent.StatusNested<A> editOrNewStatusLike(GitHubSourceStatus item);
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<GitHubSourceFluent.MetadataNested<N>> {

            public N and();
            public N endMetadata();    }


    public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,GitHubSourceSpecFluent<GitHubSourceFluent.SpecNested<N>> {

            public N and();
            public N endSpec();    }


    public interface StatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,GitHubSourceStatusFluent<GitHubSourceFluent.StatusNested<N>> {

            public N and();
            public N endStatus();    }


}

==> knative-model-5.3.0-sources.jar: annotations/io/fabric8/knative/eventing/contrib/github/v1alpha1/GitHubSourceFluent.java <==
package io.fabric8.knative.eventing.contrib.github.v1alpha1;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface GitHubSourceFluent<A extends GitHubSourceFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(int[] arg1,int arg2,int arg3);
    public A withNewApiVersion(char[] arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A withNewApiVersion(byte[] arg1,int arg2);
    public A withNewApiVersion(byte[] arg1);
    public A withNewApiVersion(char[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiVersion(String arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public GitHubSourceFluent.MetadataNested<A> withNewMetadata();
    public GitHubSourceFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public GitHubSourceFluent.MetadataNested<A> editMetadata();
    public GitHubSourceFluent.MetadataNested<A> editOrNewMetadata();
    public GitHubSourceFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public GitHubSourceSpec getSpec();
    public GitHubSourceSpec buildSpec();
    public A withSpec(GitHubSourceSpec spec);
    public Boolean hasSpec();
    public GitHubSourceFluent.SpecNested<A> withNewSpec();
    public GitHubSourceFluent.SpecNested<A> withNewSpecLike(GitHubSourceSpec item);
    public GitHubSourceFluent.SpecNested<A> editSpec();
    public GitHubSourceFluent.SpecNested<A> editOrNewSpec();
    public GitHubSourceFluent.SpecNested<A> editOrNewSpecLike(GitHubSourceSpec item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public GitHubSourceStatus getStatus();
    public GitHubSourceStatus buildStatus();
    public A withStatus(GitHubSourceStatus status);
    public Boolean hasStatus();
    public GitHubSourceFluent.StatusNested<A> withNewStatus();
    public GitHubSourceFluent.StatusNested<A> withNewStatusLike(GitHubSourceStatus item);
    public GitHubSourceFluent.StatusNested<A> editStatus();
    public GitHubSourceFluent.StatusNested<A> editOrNewStatus();
    public GitHubSourceFluent.StatusNested<A> editOrNewStatusLike(GitHubSourceStatus item);
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<GitHubSourceFluent.MetadataNested<N>> {

            public N and();
            public N endMetadata();    }


    public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,GitHubSourceSpecFluent<GitHubSourceFluent.SpecNested<N>> {

            public N and();
            public N endSpec();    }


    public interface StatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,GitHubSourceStatusFluent<GitHubSourceFluent.StatusNested<N>> {

            public N and();
            public N endStatus();    }


}
